/*
 *  Authors:  huanfuxi <huanfuxi@kylinos.cn>
 *  Authors:  liuyi <liuyi@kylinos.cn>
 *
 *  Copyright (c) KylinSoft Co., Ltd [2024].All rights reserved.
 */
#pragma once

#include "./admctl.h"
#include "./devctl.h"
#include "./exectl.h"
#include "./filectl.h"
#include "./kidctl.h"
#include "./kmodctl.h"
#include "./netctl.h"
#include "./pblkctl.h"
#include "./static_measure.h"
#include "./taskctl.h"

/**
 * @brief 功能模块的状态
 */
enum MigrationModuleStatus {
  /**
   * @brief 模块已关闭
   */
  MIGRATION_MODULE_DISBALED = 0,

  /**
   * @brief 模块已开启，且没有拦截通知或者授权对话框
   */
  MIGRATION_MODULE_ENABLED = 1,

  /**
   * @brief 模块已开启，没有拦截通知，有授权对话框
   */
  MIGRATION_MODULE_ENABLED_AND_AUTH = 2,

  /**
   * @brief 模块已开启，有拦截通知，没有授权对话框
   */
  MIGRATION_MODULE_ENABLED_AND_NOTIFY = 3,
};

struct MigrationPolicy {
  /**
   * @brief 记录从哪个json文件加载的
   */
  char *policy_path;

  struct AdmctlMigrationPolicy *admctl;
  struct DevctlMigrationPolicy *devctl;
  struct ExectlMigrationPolicy *exectl;
  struct FilectlMigrationPolicy *filectl;
  struct KidctlMigrationPolicy *kidctl;
  struct KmodctlMigrationPolicy *kmodctl;
  struct NetctlMigrationPolicy *netctl;
  struct PblkctlMigrationPolicy *pblkctl;
  struct StaticMeaureMigrationPolicy *static_measure;
  struct TaskctlMigrationPolicy *taskctl;
};

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 从指定的文件路径加载策略文件
 */
struct MigrationPolicy *migration_load_policy(const char *policy_path);

/**
 * @brief 将策略保存回原来（从哪里加载）的json文件
 * @return 0：成功，其他：失败
 */
int migration_save_policy(struct MigrationPolicy *policy);

/**
 * @brief 释放policy内存
 */
void migration_free_policy(struct MigrationPolicy *policy);

#ifdef __cplusplus
}
#endif
